@@ -1,3 +1,15 @@
+###########
+#
+#Copyright (C) <2019> <Haixu Wang>
+#
+#This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+#You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>
+###########
+
+
 #' @title Parameter Cascade Method for Ordinary Differential Equation Models
 #' @description Obtain estimates of both structural and nuisance parameters of an ODE model by parameter cascade method.
 #' @usage pcode(data, time, ode.model, par.names, state.names,
@@ -1030,7 +1042,7 @@ pcode_lkh_1d <- function(data,likelihood.fun,time, ode.model, par.names, state.n
     inner.input = list(data, Phi.mat, lambda, Qmat, Q.D1mat, quadts, quadwts, time, state.names, par.names)
 
     theta.final <- optim(par.initial, outterobj_lkh_1d, basis.initial = initial_coef, derivative.model = ode.model,
-        control = list(trace = 1), inner.input = inner.input, likelihood.fun = likelihood.fun, method = "Brent")$par
+        control = list(trace = 1,maxit = con.now$maxeval), inner.input = inner.input, likelihood.fun = likelihood.fun)$par
 
     basiscoef <- optim(initial_coef, innerobj_lkh_1d, ode.par = theta.final, input = inner.input, derive.model = ode.model,
         likelihood.fun = likelihood.fun)$par
